Theme

Struct Theme 

pub struct Theme { /* private fields */ }
A syntax-highlighting theme.

Themes are exposed as associated constants on Theme (for example Theme::TOKYO_NIGHT) and ship as scoped CSS so multiple themes can coexist on the same page without leaking styles.

use dioxus_code::Theme;
let _theme = Theme::TOKYO_NIGHT;

Implementations

Source

impl Theme

pub const ALABASTER: Theme

The alabaster syntax theme.

use dioxus_code::Theme;
let _theme = Theme::ALABASTER;
pub const AYU_DARK: Theme

The ayu-dark syntax theme.

use dioxus_code::Theme;
let _theme = Theme::AYU_DARK;
pub const AYU_LIGHT: Theme

The ayu-light syntax theme.

use dioxus_code::Theme;
let _theme = Theme::AYU_LIGHT;
pub const CATPPUCCIN_FRAPPE: Theme

The catppuccin-frappe syntax theme.

use dioxus_code::Theme;
let _theme = Theme::CATPPUCCIN_FRAPPE;
pub const CATPPUCCIN_LATTE: Theme

The catppuccin-latte syntax theme.

use dioxus_code::Theme;
let _theme = Theme::CATPPUCCIN_LATTE;
pub const CATPPUCCIN_MACCHIATO: Theme

The catppuccin-macchiato syntax theme.

use dioxus_code::Theme;
let _theme = Theme::CATPPUCCIN_MACCHIATO;
pub const CATPPUCCIN_MOCHA: Theme

The catppuccin-mocha syntax theme.

use dioxus_code::Theme;
let _theme = Theme::CATPPUCCIN_MOCHA;
pub const COBALT2: Theme

The cobalt2 syntax theme.

use dioxus_code::Theme;
let _theme = Theme::COBALT2;
pub const DAYFOX: Theme

The dayfox syntax theme.

use dioxus_code::Theme;
let _theme = Theme::DAYFOX;
pub const DESERT256: Theme

The desert256 syntax theme.

use dioxus_code::Theme;
let _theme = Theme::DESERT256;
pub const DRACULA: Theme

The dracula syntax theme.

use dioxus_code::Theme;
let _theme = Theme::DRACULA;
pub const EF_MELISSA_DARK: Theme

The ef-melissa-dark syntax theme.

use dioxus_code::Theme;
let _theme = Theme::EF_MELISSA_DARK;
pub const GITHUB_DARK: Theme

The github-dark syntax theme.

use dioxus_code::Theme;
let _theme = Theme::GITHUB_DARK;
pub const GITHUB_LIGHT: Theme

The github-light syntax theme.

use dioxus_code::Theme;
let _theme = Theme::GITHUB_LIGHT;
pub const GRUVBOX_DARK: Theme

The gruvbox-dark syntax theme.

use dioxus_code::Theme;
let _theme = Theme::GRUVBOX_DARK;
pub const GRUVBOX_LIGHT: Theme

The gruvbox-light syntax theme.

use dioxus_code::Theme;
let _theme = Theme::GRUVBOX_LIGHT;
pub const KANAGAWA_DRAGON: Theme

The kanagawa-dragon syntax theme.

use dioxus_code::Theme;
let _theme = Theme::KANAGAWA_DRAGON;
pub const LIGHT_OWL: Theme

The light-owl syntax theme.

use dioxus_code::Theme;
let _theme = Theme::LIGHT_OWL;
pub const LUCIUS_LIGHT: Theme

The lucius-light syntax theme.

use dioxus_code::Theme;
let _theme = Theme::LUCIUS_LIGHT;
pub const MELANGE_DARK: Theme

The melange-dark syntax theme.

use dioxus_code::Theme;
let _theme = Theme::MELANGE_DARK;
pub const MELANGE_LIGHT: Theme

The melange-light syntax theme.

use dioxus_code::Theme;
let _theme = Theme::MELANGE_LIGHT;
pub const MONOKAI: Theme

The monokai syntax theme.

use dioxus_code::Theme;
let _theme = Theme::MONOKAI;
pub const NORD: Theme

The nord syntax theme.

use dioxus_code::Theme;
let _theme = Theme::NORD;
pub const ONE_DARK: Theme

The one-dark syntax theme.

use dioxus_code::Theme;
let _theme = Theme::ONE_DARK;
pub const ROSE_PINE_MOON: Theme

The rose-pine-moon syntax theme.

use dioxus_code::Theme;
let _theme = Theme::ROSE_PINE_MOON;
pub const RUSTDOC_AYU: Theme

The rustdoc-ayu syntax theme.

use dioxus_code::Theme;
let _theme = Theme::RUSTDOC_AYU;
pub const RUSTDOC_DARK: Theme

The rustdoc-dark syntax theme.

use dioxus_code::Theme;
let _theme = Theme::RUSTDOC_DARK;
pub const RUSTDOC_LIGHT: Theme

The rustdoc-light syntax theme.

use dioxus_code::Theme;
let _theme = Theme::RUSTDOC_LIGHT;
pub const SOLARIZED_DARK: Theme

The solarized-dark syntax theme.

use dioxus_code::Theme;
let _theme = Theme::SOLARIZED_DARK;
pub const SOLARIZED_LIGHT: Theme

The solarized-light syntax theme.

use dioxus_code::Theme;
let _theme = Theme::SOLARIZED_LIGHT;
pub const TOKYO_NIGHT: Theme

The tokyo-night syntax theme.

use dioxus_code::Theme;
let _theme = Theme::TOKYO_NIGHT;
pub const ZENBURN: Theme

The zenburn syntax theme.

use dioxus_code::Theme;
let _theme = Theme::ZENBURN;
pub const ALL: &'static [Theme]

Every syntax theme, in declaration order.

use dioxus_code::Theme;
assert!(Theme::ALL.contains(&Theme::TOKYO_NIGHT));