pub fn BlogPostView(_: BlogPostViewProps) -> ElementExpand description
Single blog post view. Missing posts render a noindex page and return HTTP
404 during server rendering when the server feature is enabled.
Props
For details, see the props struct definition.
slug:String